﻿using Microsoft.EntityFrameworkCore;

using MyBlog.Entity;
using MyBlog.IRepository;
using MyBlog.Model;

using System;
using System.Collections.Generic;
using System.Linq;
using System.Linq.Expressions;
using System.Threading.Tasks;

namespace MyBlog.Repository
{
    public class BlogNewsRepository : BaseRepository<BlogNews>, IBlogNewsRepository
    {
        private readonly MyContext _myContext;
        private readonly DbSet<BlogNews> blogNews;

        public BlogNewsRepository(MyContext context) : base(context)
        {
            _myContext = context;
            blogNews = context.Set<BlogNews>();
        }

        public override async Task<BlogNews> DeleteAsync(BlogNews entity)
        {
            if (entity == null)
            {
                throw new ArgumentNullException($"{nameof(entity)} is not found");
            }

            try
            {
                blogNews.Remove(entity);
                await _myContext.SaveChangesAsync();

                return entity;
            }
            catch (Exception e)
            {
                throw new Exception($"{nameof(entity)} could not be deleted: {e.Message}");
            }
        }

        public async override Task<List<BlogNews>> QueryAsync()
        {
            return await blogNews
                .Include(x => x.WriterInfo)
                .ToListAsync();
        }

        public async override Task<List<BlogNews>> QueryAsync(Expression<Func<BlogNews, bool>> func)
        {
            return await blogNews.Where(func)
                .Include(x => x.TypeInfo)
                .Include(x => x.WriterInfo)
                .ToListAsync();
        }

        public async override Task<List<BlogNews>> QueryAsync(int page, int size)
        {
            var entity = blogNews
                .Include(x => x.TypeInfo)
                .Include(x => x.WriterInfo);

            return await entity.OrderByDescending(x => x.Time)
               .Skip(size * (page - 1))
               .Take(size)
               .ToListAsync();
        }

        public async override Task<List<BlogNews>> QueryAsync(Expression<Func<BlogNews, bool>> func, int page, int size)
        {
            var entity = blogNews
                .Include(x => x.TypeInfo)
                .Include(x => x.WriterInfo);

            var funcInfo = entity.Where(func);

            return await funcInfo
                .OrderByDescending(x => x.Time)
                .Skip(size * (page - 1))
                .Take(size).ToListAsync();
        }
    }
}