﻿using MyBlog.IRepository;
using MyBlog.IService;

using System;
using System.Collections.Generic;
using System.Linq.Expressions;
using System.Threading.Tasks;

namespace MyBlog.Service
{
    public class BaseService<TEntity> : IBaseService<TEntity> where TEntity : class, new()
    {
        private IBaseRepository<TEntity> _baseRepository;

        public BaseService(IBaseRepository<TEntity> baseRepository)
        {
            _baseRepository = baseRepository;
        }

        public async Task<TEntity> CreateAsync(TEntity entity)
        {
            return await _baseRepository.CreateAsync(entity);
        }

        public async Task<TEntity> DeleteAsync(TEntity entity)
        {
            return await _baseRepository.DeleteAsync(entity);
        }

        public async Task<TEntity> EditAsync(TEntity entity)
        {
            return await _baseRepository.EditAsync(entity);
        }

        public async Task<TEntity> FindAsync(int id)
        {
            return await _baseRepository.FindAsync(id);
        }

        public async Task<TEntity> FindAsync(Expression<Func<TEntity, bool>> func)
        {
            return await _baseRepository.FindAsync(func);
        }

        public virtual async Task<List<TEntity>> QueryAsync()
        {
            return await _baseRepository.QueryAsync();
        }

        public virtual async Task<List<TEntity>> QueryAsync(Expression<Func<TEntity, bool>> func)
        {
            return await _baseRepository.QueryAsync(func);
        }

        public virtual async Task<List<TEntity>> QueryAsync(int page, int size)
        {
            return await _baseRepository.QueryAsync(page, size);
        }

        public virtual async Task<List<TEntity>> QueryAsync(Expression<Func<TEntity, bool>> func, int page, int size)
        {
            return await _baseRepository.QueryAsync(func, page, size);
        }
    }
}