﻿using Microsoft.AspNetCore.Components;
using Microsoft.JSInterop;

using System;
using System.Threading.Tasks;

namespace MyBlog.Client.Commons
{
    public class Common
    {
        private readonly IJSRuntime _jsRuntime;
        private readonly NavigationManager _navigationManager;

        public Common(IJSRuntime jsRuntime, NavigationManager navigationManager)
        {
            _jsRuntime = jsRuntime;
            _navigationManager = navigationManager;
        }

        public async ValueTask InvokeAsync(string identifier, params object[] args)
        {
            await _jsRuntime.InvokeVoidAsync(identifier, args);
        }

        public async ValueTask<TValue> InvokeAsync<TValue>(string identifier, params object[] args)
        {
            return await _jsRuntime.InvokeAsync<TValue>(identifier, args);
        }

        public async Task SetStorageAsync(string name, string value)
        {
            await InvokeAsync("window.func.setStorage", name, value);
        }

        public async Task<string> GetStorageAsync(string name)
        {
            return await InvokeAsync<string>("window.func.getStorage", name);
        }

        public async Task NavigateTo(string url, bool forceLoad = false)
        {
            _navigationManager.NavigateTo(url, forceLoad);

            await Task.CompletedTask;
        }

        public async Task<Uri> CurrentUri()
        {
            var uri = _navigationManager.ToAbsoluteUri(_navigationManager.Uri);

            return await Task.FromResult(uri);
        }

        public async Task SwitchEditorTheme(string currentTheme)
        {
            var editorTheme = currentTheme == "Light" ? "default" : "dark";

            await SetStorageAsync("editorTheme", editorTheme);

            await InvokeAsync("window.markdown.switchEditorTheme");
        }
    }
}