﻿using Microsoft.AspNetCore.Components;
using Microsoft.JSInterop;

using MyBlog.Model.DTO;
using MyBlog.Shared.ApiResult;

using System;
using System.Collections.Generic;
using System.Net.Http.Headers;
using System.Net.Http.Json;
using System.Threading.Tasks;

namespace MyBlog.Client.Pages.Admin
{
    public partial class Post
    {
        public static Func<Task> action;

        public bool Open { get; set; }

        [Parameter]
        public int? Id { get; set; }

        public List<TypeInfoDTO> tags { get; set; }

        private bool isLoading = true;

        private BlogNewsDetailDTO blog;

        protected override async Task OnInitializedAsync()
        {
            action = ChangeOpenStatus;

            var token = await Common.GetStorageAsync("token");
            Http.DefaultRequestHeaders.Authorization = new AuthenticationHeaderValue("Bearer", token);

            if (Id.HasValue)
            {
                var result = await Http.GetFromJsonAsync<ApiResponse<BlogNewsDetailDTO>>($"/api/BlogNews/GetBlogNewsDetail?id={Id}");
                if (result.Status == "200")
                {
                    blog = result.Data;
                }
            }
            else
            {
                blog = new BlogNewsDetailDTO()
                {
                    WriterName = await Common.GetStorageAsync("Author"),
                    Time = DateTime.UtcNow.ToString(),
                };
            }

            var resultTags = await Http.GetFromJsonAsync<ApiResponse<List<TypeInfoDTO>>>("api/Type/GetTypes");

            tags = resultTags.Status == "200" ? resultTags.Data : new List<TypeInfoDTO>();

            await Common.InvokeAsync("window.markdown.renderEditor");

            isLoading = !isLoading;
        }

        [JSInvokable("showbox")]
        public static void ShowBox()
        {
            action.Invoke();
        }

        private async Task SubmitAsync()
        {
            if (tags.Count == 0 || blog.TypeInfoId == 0)
            {
                await Alert();
                return;
            }

            var responseMessage = Id.HasValue ? await Http.PutAsJsonAsync("/api/BlogNews/Edit", blog) : await Http.PostAsJsonAsync("/api/BlogNews/Create", blog);

            var result = await responseMessage.Content.ReadFromJsonAsync<ApiResponse<BlogNewsDetailDTO>>();

            if (result.Status == "200")
            {
                await Common.NavigateTo("/admin/posts");
            }
        }

        private async Task ChangeOpenStatus()
        {
            Open = true;

            try
            {
                var markdown = await Common.InvokeAsync<string>("editor.getMarkdown");
                var html = await Common.InvokeAsync<string>("editor.getHTML");

                if (string.IsNullOrEmpty(blog.Title) || string.IsNullOrEmpty(markdown) || string.IsNullOrEmpty(html))
                {
                    await Alert();
                }

                blog.Content = markdown;
                blog.HtmlContent = html;
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
            }

            StateHasChanged();
        }

        private async Task Alert()
        {
            Open = false;

            await Common.InvokeAsync("alert", "\n💥💢好像漏了点什么吧💢💥");
            return;
        }
    }
}