﻿using Microsoft.AspNetCore.Components;

using MyBlog.Model.DTO;
using MyBlog.Shared.ApiResult;

using System;
using System.Collections.Generic;
using System.Linq;
using System.Net.Http.Headers;
using System.Net.Http.Json;
using System.Threading.Tasks;

namespace MyBlog.Client.Pages.Admin
{
    public partial class Posts
    {
        [Parameter]
        public int? page { get; set; }

        private int Limit = 15;

        private int TotalPage;

        private List<BlogNewsDTO> blogNews;

        protected override async Task OnInitializedAsync()
        {
            var token = await Common.GetStorageAsync("token");
            Http.DefaultRequestHeaders.Authorization = new AuthenticationHeaderValue("Bearer", token);

            page = page.HasValue ? page : 1;

            await RenderPage(page);
        }

        private async Task DeleteAsync(int id)
        {
            var confirmed = await Common.InvokeAsync<bool>("confirm", "\n💥💢真的要干掉这篇该死的文章吗💢💥");

            if (confirmed)
            {
                var response = await Http.DeleteAsync($"/api/BlogNews/Delete?id={id}");

                var result = await response.Content.ReadFromJsonAsync<ApiResponse<BlogNewsDetailDTO>>();

                if (result.Status == "200")
                {
                    await RenderPage(page);
                }
            }
        }

        private async Task RenderPage(int? page)
        {
            var result = await Http.GetFromJsonAsync<ApiResponse<List<BlogNewsDTO>>>($"/api/BlogNews/GetBlogNewsPage?page={page}&size={Limit}");

            if (result.Status != "200")
            {
                await Common.NavigateTo("/");
            }

            blogNews = result.Data;
            TotalPage = (int)Math.Ceiling(blogNews.Count() / (double)Limit);
        }
    }
}