﻿using MyBlog.Model;
using MyBlog.Model.DTO;
using MyBlog.Shared.ApiResult;

using System.Collections.Generic;
using System.Net.Http.Headers;
using System.Net.Http.Json;
using System.Threading.Tasks;

namespace MyBlog.Client.Pages.Admin
{
    public partial class Tags
    {
        public bool Open { get; set; }

        private string tagName;

        private int id;

        private List<TypeInfoDTO> tags;

        protected override async Task OnInitializedAsync()
        {
            var token = await Common.GetStorageAsync("token");
            Http.DefaultRequestHeaders.Authorization = new AuthenticationHeaderValue("Bearer", token);

            tags = await FetchData();
        }

        private async Task DeleteAsync(int id)
        {
            bool confirmed = await Common.InvokeAsync<bool>("confirm", "\n💥💢真的要干掉这个该死的标签吗💢💥");

            if (confirmed)
            {
                var response = await Http.DeleteAsync($"/api/Type/Delete?id={id}");

                var result = await response.Content.ReadFromJsonAsync<ApiResponse<TypeInfo>>();

                if (result.Status == "200")
                {
                    tags = await FetchData();
                }
            }
        }

        private void ShowBox(TypeInfoDTO dto = null)
        {
            Open = true;
            id = 0;

            // 新增
            if (dto == null)
            {
                tagName = null;
            }
            else // 更新
            {
                id = dto.Id;
                tagName = dto.Name;
            }
        }

        private async Task SubmitAsync()
        {
            var input = new WriterInfo()
            {
                Id = id,
                Name = tagName.Trim()
            };

            if (string.IsNullOrEmpty(input.Name))
            {
                return;
            }

            var response = id > 0 ?
                await Http.PutAsJsonAsync("api/Type/Edit", input) :
                await Http.PostAsJsonAsync("api/Type/Create", input);

            var result = await response.Content.ReadFromJsonAsync<ApiResponse<TypeInfoDTO>>();
            if (result.Status == "200")
            {
                tags = await FetchData();
                Open = false;
            }
        }

        private async Task<List<TypeInfoDTO>> FetchData()
        {
            var result = await Http.GetFromJsonAsync<ApiResponse<List<TypeInfoDTO>>>("api/Type/GetTypes");
            if (result.Status != "200")
            {
                return new List<TypeInfoDTO>();
            }

            return result.Data;
        }
    }
}