﻿using MyBlog.Model;
using MyBlog.Model.DTO;
using MyBlog.Shared.ApiResult;

using System.Collections.Generic;
using System.Net.Http.Headers;
using System.Net.Http.Json;
using System.Threading.Tasks;

namespace MyBlog.Client.Pages.Admin
{
    public partial class Writers
    {
        private bool Open { get; set; }

        private string name, userName, password;

        private int id;

        private List<WriterInfoDTO> writers;

        protected override async Task OnInitializedAsync()
        {
            var token = await Common.GetStorageAsync("token");
            Http.DefaultRequestHeaders.Authorization = new AuthenticationHeaderValue("Bearer", token);

            var result = await FetchData();
            if (result.Status == "200")
            {
                writers = result.Data;
            }
            else
            {
                writers = new List<WriterInfoDTO>();
            }
        }

        private async Task DeleteAsync(int id)
        {
            Open = false;

            bool confirmed = await Common.InvokeAsync<bool>("confirm", "\n💥💢真的要干掉这个该死的作者吗💢💥");

            if (confirmed)
            {
                var response = await Http.DeleteAsync($"api/WriterInfo/Delete?id={id}");

                var result = await response.Content.ReadFromJsonAsync<ApiResponse<WriterInfoDTO>>();

                if (result.Status == "200")
                {
                    var wrterList = await FetchData();
                    if (wrterList.Status == "200")
                    {
                        writers = wrterList.Data;
                    }
                    else
                    {
                        writers = new List<WriterInfoDTO>();
                    }
                }
            }
        }

        private void ShowBox(WriterInfoDTO writer = null)
        {
            Open = true;
            id = 0;

            if (writer == null)
            {
                name = null;
                userName = null;
                password = null;
            }
            else
            {
                id = writer.Id;
                name = writer.Name;
                userName = writer.UserName;
                password = null;
            }
        }

        private async Task SubmitAsync()
        {
            var input = new WriterInfo
            {
                UserName = userName.Trim(),
                UserPwd = password.Trim(),
                Name = name.Trim()
            };

            if (string.IsNullOrEmpty(input.UserName) || string.IsNullOrEmpty(input.UserPwd) || string.IsNullOrEmpty(name))
            {
                return;
            }

            var response = id > 0 ? await Http.PutAsJsonAsync("api/WriterInfo/Edit", input) : await Http.PostAsJsonAsync("api/WriterInfo/Create", input);
            var result = await response.Content.ReadFromJsonAsync<ApiResponse<WriterInfoDTO>>();

            if (result.Status == "200")
            {
                var wrterList = await FetchData();
                if (wrterList.Status == "200")
                {
                    writers = wrterList.Data;
                }
                else
                {
                    writers = new List<WriterInfoDTO>();
                }

                Open = false;
            }
        }

        private async Task<ApiResponse<List<WriterInfoDTO>>> FetchData()
        {
            return await Http.GetFromJsonAsync<ApiResponse<List<WriterInfoDTO>>>("api/WriterInfo/GetAllWriters");
        }
    }
}