﻿using Microsoft.AspNetCore.Components;

using MyBlog.Model.DTO;
using MyBlog.Model.JWT;
using MyBlog.Shared.ApiResult;

using System;
using System.Net.Http.Json;
using System.Threading.Tasks;

namespace MyBlog.Client.Shared
{
    public partial class AdminLayout
    {
        [Parameter]
        public RenderFragment ChildContent { get; set; }

        private bool isLogin { get; set; }

        protected override async Task OnInitializedAsync()
        {
            var token = await Common.GetStorageAsync("token");
            var refresh_token = await Common.GetStorageAsync("refresh_token");

            if (!string.IsNullOrEmpty(token) && !string.IsNullOrEmpty(refresh_token))
            {
                isLogin = true;

                var refreshToken = new RefreshTokenDTO()
                {
                    Token = token,
                    RefreshToken = refresh_token
                };

                try
                {
                    var response = await Http.PostAsJsonAsync($"api/Authorize/RefreshToken", refreshToken);

                    var result = await response.Content.ReadFromJsonAsync<ApiResponse<AuthResult>>();

                    if (result.Status == "200")
                    {
                        if (result.Data.Success)
                        {
                            await Common.SetStorageAsync("token", result.Data.Token);
                            await Common.SetStorageAsync("refresh_token", result.Data.RefreshToken);
                        }
                        else
                        {
                            isLogin = false;

                            await Common.NavigateTo("/login");
                        }
                    }
                    else
                    {
                        Console.WriteLine(result.Message);
                    }
                }
                catch (Exception e)
                {
                    Console.WriteLine(e.Message);
                }
            }
            else
            {
                isLogin = false;

                await Common.NavigateTo("/login");
            }
        }
    }
}