﻿using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;

using MyBlog.IService;
using MyBlog.Model.DTO;
using MyBlog.Server.Utility.Filter;
using MyBlog.Shared.Utility.ApiResult;

using System;
using System.Linq;
using System.Reflection;
using System.Threading.Tasks;

using TypeInfo = MyBlog.Model.TypeInfo;

namespace MyBlog.Server.Controllers
{
    [Route("api/[controller]/[action]")]
    [ApiController]
    public class TypeController : ControllerBase
    {
        private readonly ITypeInfoService _typeInfoService;
        private readonly IBlogNewsService _blogNewsService;

        public TypeController(ITypeInfoService typeInfoService, IBlogNewsService blogNewsService)
        {
            _typeInfoService = typeInfoService;
            _blogNewsService = blogNewsService;
        }

        [HttpGet]
        [TypeFilter(typeof(CustomResourceFilterAttribute))]
        public async Task<ApiResult> GetTypes()
        {
            var types = await _typeInfoService.QueryAsync();

            var entity = types.Select(x => new TypeInfoDTO
            {
                Id = x.Id,
                Name = x.Name,
                Count = x.Blogs.Count
            });

            return new ApiResult(ResultCode.SUCCESS, entity);
        }

        [HttpPost]
        [Authorize]
        public async Task<ApiResult> Create(TypeInfo typeInfo)
        {
            if (string.IsNullOrWhiteSpace(typeInfo.Name))
            {
                return new ApiResult(ResultCode.FALL, "类型名称不能为空");
            }

            try
            {
                var entity = await _typeInfoService.CreateAsync(typeInfo);

                return entity != typeInfo ? new ApiResult(ResultCode.FALL) : new ApiResult(ResultCode.SUCCESS, entity);
            }
            catch (Exception e)
            {
                return new ApiResult(ResultCode.FALL, $"{e.Message}");
            }
        }

        [HttpDelete]
        [Authorize]
        public async Task<ApiResult> Delete(int id)
        {
            var type = await _typeInfoService.FindAsync(id);
            if (type == null)
            {
                return new ApiResult(ResultCode.FALL, $"Id {id} not found");
            }

            try
            {
                await _typeInfoService.DeleteAsync(type);
                return new ApiResult(ResultCode.SUCCESS, type);
            }
            catch (Exception e)
            {
                return new ApiResult(ResultCode.FALL, $"{e.Message}");
            }
        }

        [HttpPut]
        [Authorize]
        public async Task<ApiResult> Edit(TypeInfo typeInfo)
        {
            var type = await _typeInfoService.FindAsync(typeInfo.Id);
            if (type == null)
            {
                return new ApiResult(ResultCode.FALL, $"Id {typeInfo.Id} not found");
            }

            type.Name = typeInfo.Name;
            try
            {
                var entity = await _typeInfoService.EditAsync(type);
                return entity != type ? new ApiResult(ResultCode.FALL, "edit  fall") : new ApiResult(ResultCode.SUCCESS, entity);
            }
            catch (Exception e)
            {
                return new ApiResult(ResultCode.FALL, $"{e.Message}");
            }
        }
    }
}