﻿using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.Filters;
using Microsoft.Extensions.Caching.Memory;

using System;

namespace MyBlog.Server.Utility.Filter
{
    public class CustomResourceFilterAttribute : Attribute, IResourceFilter
    {
        private readonly IMemoryCache _cache;

        public CustomResourceFilterAttribute(IMemoryCache cache)
        {
            _cache = cache;
        }

        public void OnResourceExecuted(ResourceExecutedContext context)
        {
            var path = context.HttpContext.Request.Path;
            var route = context.HttpContext.Request.QueryString.Value;
            var key = path + route;
            _cache.Set(key, context.Result, TimeSpan.FromMinutes(1));
        }

        public void OnResourceExecuting(ResourceExecutingContext context)
        {
            var path = context.HttpContext.Request.Path;
            var route = context.HttpContext.Request.QueryString.Value;
            var key = path + route;
            if (_cache.TryGetValue(key, out object value))
            {
                context.Result = value as IActionResult;
            }
        }
    }
}