﻿using System;
using System.Reflection;

namespace MyBlog.Shared.Utility.ApiResult
{
    public static class CustomEnumExtenions
    {
        /// <summary>
        /// 获取枚举字段的特性
        /// </summary>
        /// <returns></returns>
        public static string GetAttributeValue(this Enum thisValue)
        {
            FieldInfo field = thisValue.GetType().GetField(thisValue.ToString());
            var attr = (Attribute.GetCustomAttribute(field, typeof(Desc)) as Desc);
            return attr == null ? string.Empty : attr.Value;
        }

        public static T GetAttribute<T>(this Enum thisValue) where T : class
        {
            FieldInfo field = thisValue.GetType().GetField(thisValue.ToString());
            var attr = (Attribute.GetCustomAttribute(field, typeof(T)) as T);
            return attr ?? null;
        }

        /// <summary>
        /// 获取枚举字段的名称
        /// </summary>
        /// <returns></returns>
        public static string GetName(this Enum thisValue)
        {
            return Enum.GetName(thisValue.GetType(), thisValue);
        }

        /// <summary>
        /// 获取枚举字段值
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <returns></returns>
        public static T GetValue<T>(this Enum thisValue)
        {
            return (T)Enum.Parse(thisValue.GetType(), thisValue.ToString());
        }
    }

    [Serializable]
    [AttributeUsage(AttributeTargets.Field, AllowMultiple = false, Inherited = false)]
    public class Desc : Attribute
    {
        public string Value { get; private set; }

        public Desc(string value)
        {
            Value = value;
        }
    }
}